floem-ui-kit 0.0.1

Ready-to-use UI components for the Floem GUI library
floem-ui-kit-0.0.1 is not a library.
Visit the last successful build: floem-ui-kit-0.1.0

This is a placeholder for Floem UI Kit.

Since crates.io does not support Git dependencies, and Floem is only available as a Git dependency, Floem UI Kit cannot publish yet. In the meantime, you can install Floem UI Kit as a Git dependency.